==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/elastictranscoder/kotlin/inputs/PipelineContentConfigArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.elastictranscoder.kotlin.inputs

import com.pulumi.aws.elastictranscoder.inputs.PipelineContentConfigArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property bucket The Amazon S3 bucket in which you want Elastic Transcoder to save transcoded files and playlists.
 * @property storageClass The Amazon S3 storage class, `Standard` or `ReducedRedundancy`, that you want Elastic Transcoder to assign to the files and playlists that it stores in your Amazon S3 bucket.
 */
public data class PipelineContentConfigArgs(
    public val bucket: Output<String>? = null,
    public val storageClass: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.elastictranscoder.inputs.PipelineContentConfigArgs> {
    override fun toJava(): com.pulumi.aws.elastictranscoder.inputs.PipelineContentConfigArgs =
        com.pulumi.aws.elastictranscoder.inputs.PipelineContentConfigArgs.builder()
            .bucket(bucket?.applyValue({ args0 -> args0 }))
            .storageClass(storageClass?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [PipelineContentConfigArgs].
 */
@PulumiTagMarker
public class PipelineContentConfigArgsBuilder internal constructor() {
    private var bucket: Output<String>? = null

    private var storageClass: Output<String>? = null

    /**
     * @param value The Amazon S3 bucket in which you want Elastic Transcoder to save transcoded files and playlists.
     */
    @JvmName("vgwgpmvvlosagfsj")
    public suspend fun bucket(`value`: Output<String>) {
        this.bucket = value
    }

    /**
     * @param value The Amazon S3 storage class, `Standard` or `ReducedRedundancy`, that you want Elastic Transcoder to assign to the files and playlists that it stores in your Amazon S3 bucket.
     */
    @JvmName("vjyhytgflvddhedl")
    public suspend fun storageClass(`value`: Output<String>) {
        this.storageClass = value
    }

    /**
     * @param value The Amazon S3 bucket in which you want Elastic Transcoder to save transcoded files and playlists.
     */
    @JvmName("mldlhuirtbvuusmj")
    public suspend fun bucket(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.bucket = mapped
    }

    /**
     * @param value The Amazon S3 storage class, `Standard` or `ReducedRedundancy`, that you want Elastic Transcoder to assign to the files and playlists that it stores in your Amazon S3 bucket.
     */
    @JvmName("lykwhqitnwlhwlum")
    public suspend fun storageClass(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.storageClass = mapped
    }

    internal fun build(): PipelineContentConfigArgs = PipelineContentConfigArgs(
        bucket = bucket,
        storageClass = storageClass,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/elastictranscoder/kotlin/inputs/PipelineContentConfigArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.elastictranscoder.kotlin.inputs

import com.pulumi.aws.elastictranscoder.inputs.PipelineContentConfigArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property bucket The Amazon S3 bucket in which you want Elastic Transcoder to save transcoded files and playlists.
 * @property storageClass The Amazon S3 storage class, `Standard` or `ReducedRedundancy`, that you want Elastic Transcoder to assign to the files and playlists that it stores in your Amazon S3 bucket.
 */
public data class PipelineContentConfigArgs(
    public val bucket: Output<String>? = null,
    public val storageClass: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.elastictranscoder.inputs.PipelineContentConfigArgs> {
    override fun toJava(): com.pulumi.aws.elastictranscoder.inputs.PipelineContentConfigArgs =
        com.pulumi.aws.elastictranscoder.inputs.PipelineContentConfigArgs.builder()
            .bucket(bucket?.applyValue({ args0 -> args0 }))
            .storageClass(storageClass?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [PipelineContentConfigArgs].
 */
@PulumiTagMarker
public class PipelineContentConfigArgsBuilder internal constructor() {
    private var bucket: Output<String>? = null

    private var storageClass: Output<String>? = null

    /**
     * @param value The Amazon S3 bucket in which you want Elastic Transcoder to save transcoded files and playlists.
     */
    @JvmName("ycoddxplcxxsccut")
    public suspend fun bucket(`value`: Output<String>) {
        this.bucket = value
    }

    /**
     * @param value The Amazon S3 storage class, `Standard` or `ReducedRedundancy`, that you want Elastic Transcoder to assign to the files and playlists that it stores in your Amazon S3 bucket.
     */
    @JvmName("iabemcyvsievvdpt")
    public suspend fun storageClass(`value`: Output<String>) {
        this.storageClass = value
    }

    /**
     * @param value The Amazon S3 bucket in which you want Elastic Transcoder to save transcoded files and playlists.
     */
    @JvmName("abnikxisghrtxaoi")
    public suspend fun bucket(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.bucket = mapped
    }

    /**
     * @param value The Amazon S3 storage class, `Standard` or `ReducedRedundancy`, that you want Elastic Transcoder to assign to the files and playlists that it stores in your Amazon S3 bucket.
     */
    @JvmName("hafrsuidmrwuxapf")
    public suspend fun storageClass(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.storageClass = mapped
    }

    internal fun build(): PipelineContentConfigArgs = PipelineContentConfigArgs(
        bucket = bucket,
        storageClass = storageClass,
    )
}
